@@ -1,4 +1,5 @@
-package MyAtom::Model::Schema;
+package # hide from PAUSE
+    MyAtom::Model::Schema;
 
 use strict;
 use base qw( DBIx::Class::Schema::Loader );
